this.name					= "aquatics_populator";
this.author					= "Thargoid";
this.copyright				= "Creative Commons: attribution, non-commercial, sharealike with clauses - see readme.txt";
this.description			= "Adds the hammerhead haulers and platforms, plus runs the mission offering.";
this.version				= "2.31";
"use strict";

/*
External control of adding system platforms in systems and interstellar space is now available to other OXPs.
To use simply set worldScripts["aquatics_populator"].allowInterstellar = false or worldScripts["aquatics_populator"].allowPlatforms = false to suppress their appearance in the next system or IS entry. They will self reset to true upon arrival after the set-up is blocked.
*/

this.startUp = function()
	{
	this.allowInterstellar = true;
	this.allowPlatforms = true;
	this.platformMessage = null;
	this.launchFlag = null;
	missionVariables.aquatics_cloakRandom = Math.random();
	}

this.systemWillPopulate = function()	
	{
	this.addHauler();
	this.addPlatforms();
	this.addHQ();
	}
	
this.interstellarSpaceWillPopulate = function()
	{ this.addPlatforms(); }
	
this.shipWillEnterWitchspace = function()
	{
	this.platformMessage = null;
	this.launchFlag = null;

	if(galaxyNumber == 2 && system.ID == 99 && worldScripts.PlanetFall) // if Planetfall is loaded and we're leaving Aqualina
		{ worldScripts.PlanetFall.planetFallOverride = null; } // reset the override 

	if(missionVariables.aquatics_krakenMission == "BEGUN")
		{
		missionVariables.aquatics_krakenMission = "FAILED";
		mission.setInstructionsKey(null);
		}
	}

this.shipWillExitWitchspace = function()
	{
	if(missionVariables.aquatics_reputation < 0 && Math.random() > 0.5)
		{ missionVariables.aquatics_reputation++; }
	}

this.shipWillLaunchFromStation = function(station)
	{
	this.launchFlag = true;
	
	if(galaxyNumber == 2 && system.ID == 99 && station.hasRole("aquatics_HQ"))
		{
		if(missionVariables.aquatics_krakenMission == "BRIEFING_1" || missionVariables.aquatics_krakenMission == "BRIEFING_2" || missionVariables.aquatics_krakenMission == "IMMEDIATE_OFFER")
			{ missionVariables.aquatics_krakenMission = "MAKE_OFFER"; }

		if(missionVariables.aquatics_krakenMission == "NOT_WELCOME" || missionVariables.aquatics_krakenMission == "KICK_OUT")
			{ missionVariables.aquatics_krakenMission = "CASE_CLOSED"; }
			
		if(worldScripts.PlanetFall) // if Planetfall is loaded
			{ worldScripts.PlanetFall.planetFallOverride = true; } // set the override, so only external OXP locations appear 

		if(missionVariables.aquatics_krakenMission == "BEGUN" && system.countShipsWithRole("aquatics_kraken") == 0)
			{ this.addKraken(); } 
		}
	}

this.shipLaunchedFromStation = this.shipEnteredStationAegis = function()
	{
	if(this.platformMessage == true)
		{
		player.commsMessage("ALERT! This is " + system.name + " station. Communication has been lost with the system platform. We are investigating, please proceed with extreme caution!", 6);
		this.platformMessage = null;
		}
	}

this.addHQ = function()
	{
	if(galaxyNumber == 2 && system.ID == 99 && system.countShipsWithRole("aquatics_HQ") == 0)
		{
//		this.$spawnedHQ = system.addShipsToRoute("aquatics_HQ", 1, 0.9, "sp")

		var x_coord = system.scrambledPseudoRandomNumber(12) * 25E3;
		var y_coord = system.scrambledPseudoRandomNumber(13) * 25E3;
		var z_coord = system.mainPlanet.radius + (0.15 * (system.sun.position.distanceTo(system.mainPlanet.position) - system.sun.radius - system.mainPlanet.radius));
		var exactPosition = Vector3D(x_coord, y_coord, z_coord).fromCoordinateSystem("psm");

		system.setPopulator("aquatics_HQ", {
			callback: function(pos) {			
				this.$spawnedHQ = system.addShips("aquatics_HQ", 1, pos, 0);					
				system.addShips("aquatics_platform", 1, this.$spawnedHQ[0].position.add([20000,0,0]));
				system.addShips("aquatics_platform", 1, this.$spawnedHQ[0].position.add([-20000,0,0]));
			}.bind(this),
			location: "COORDINATES",
			coordinates: exactPosition,
			deterministic: true
			}
		)
		
		if(worldScripts.PlanetFall) // if Planetfall is loaded
			{ worldScripts.PlanetFall.planetFallOverride = true;} // set the override, so only external OXP locations appear
		
		system.addShips("aquatics_platform", 1, [0, 0, 0], 22000);
		}	
	}
	
this.addHauler = function()
	{
	if(this.launchFlag || worldScripts["bigShips_populator"]) // don't place anything if we've already tried to populate the system or bigShips can handle it
		{ return; }
	
	if(Math.random() < (0.1 + ((system.techLevel + system.government)/50)) )
		{
		this.zDistance = ((Math.random() * 0.75) + 0.15);
		system.addShipsToRoute("aquatics_hammerHead", 1, this.zDistance, "pw");
		log(this.name, "Hammerhead hauler added to the " + system.name + " system by populator script.");
		}
	}

this.addPlatforms = function()
	{
	if(system.isInterstellarSpace)
		{
		if(Math.random() < 0.05 && this.allowInterstellar)
			{
			system.addShips("aquatics_platform", 1, player.ship.position, 20000);
			log(this.name, "System platform added in interstellar space by populator script.");
			}
		this.allowInterstellar = true;	
		return;
		}

	if(this.launchFlag || this.allowPlatforms === false) 
		{ // don't place anything if the system is going nova, we've already tried to populate the system or the external block is set
		this.allowPlatforms = true;
		return;
		}
	
	if(galaxyNumber == 2 && system.ID == 99) // if we're at Aqualina 
		{ return; } // no need to go any further for this system
		

	if(Math.random() < ((system.techLevel + system.government)/100))
		{
		system.addShips("aquatics_platform", 1, [0, 0, 0], 22000);
		log(this.name, "System platform near the " + system.name + " witchpoint.");
		}


	if(Math.random() < ((system.techLevel + system.government)/50))
		{
		if(Math.random() < 0.05)
			{
			system.addShips("aquatics_piratePlatform", 1, system.mainStation.position, 22000);
			system.addShips("aquatics_destroyer", 1, system.mainStation.position, 22000);
			system.addShips("aquatics_defender", 2, system.mainStation.position, 22000);
			this.platformMessage = true;
			}
		else
			{
			system.addShips("aquatics_platform", 1, system.mainStation.position, 22000);
			this.platformMessage = null;
			}
		}
	}

this.addKraken = function()
	{
	this.zDistance = ((Math.random() * 0.4) + 0.4);
	system.addShipsToRoute("aquatics_kraken", 1, this.zDistance, "pw");

	var addCounter = 0 ; 	// reset the counter
	var policeCount = Math.ceil(Math.random() * 3) + 1; // random number between 2 and 4
	for(addCounter = 0; addCounter < policeCount; addCounter++) // add police tasked to pursue and destroy the Kraken
		{
		this.zDistance = ((Math.random() * 0.9) + 0.05);
		system.addShipsToRoute("aquatics_krakenPolice", 1, this.zDistance, "pw"); 
		}

	log(this.name, "AHC Kraken and " + policeCount + " pursuing security forces added to Aqualina system by populator script.");
	}

// mission-related events below here.

this.shipDockedWithStation = function(station)
	{
	if(galaxyNumber == 2 && system.ID == 99 && station.hasRole("aquatics_HQ")) // if we're docked at the HQ
		{
		missionVariables.aquatics_cloakRandom = Math.random();

		if(player.score > 511 && missionVariables.aquatics_krakenMission == "UNAVAILABLE")
			{
			missionVariables.aquatics_krakenMission = "MAKE_OFFER";
			}
		}
	}
	
this.notWelcome = function()
	{
	missionVariables.aquatics_krakenMission = "CASE_CLOSED";
	player.ship.launch();
	}
	
this.missionChoice = function(choice)
	{
	switch(choice)
		{
		case "AQUATICS_1_ACCEPTED":
			{
			missionVariables.aquatics_krakenMission = "BRIEFING_1";
			mission.runScreen({title: "Mission Briefing", messageKey:"aquatics_krakenBriefing1", background:"aquatics_logo.png"}, this.missionChoice);
			mission.setInstructionsKey("aquatics_krakenShortHunt");
			break;
			}

		case "AQUATICS_2_REJECTED":
			{
			mission.runScreen({title: "Are you sure?", messageKey:"aquatics_firstDecline", background:"aquatics_logo.png", choicesKey:"aquatics_secondChoice"}, this.missionChoice);
			break;
			}

		case "AQUATICS_3_REJECTED":
			{
			missionVariables.aquatics_krakenMission = "KICK_OUT"
			mission.runScreen({title: "Well if that's your attitude!", messageKey:"aquatics_secondDecline", background:"aquatics_logo.png"});
			break;
			}
		}
	}

this.missionScreenOpportunity = function()
	{
	if(galaxyNumber == 2 && system.ID == 99 && player.ship.docked && player.ship.dockedStation.hasRole("aquatics_HQ")) // if we're docked at the HQ
		{

		if(guiScreen == "GUI_SCREEN_MISSION") // if something else has taken the mission screen.
			{
			return;
			}

		if(missionVariables.aquatics_reputation < 0)
			{
			mission.runScreen({title: "Uh-oh!", messageKey:"aquatics_notWelcome", background:"aquatics_logo.png"}, this.notWelcome);
			return;
			}

		switch(missionVariables.aquatics_krakenMission)
			{
			case "KICK_OUT": // if we've rejected the mission
				{
				missionVariables.aquatics_reputation = -10;
				this.notWelcome();
				return;
				}
			
			case "MAKE_OFFER": // if we've been here before, but didn't have high enough rank
				{
				mission.runScreen({title: "Time for a beer, but...", messageKey:"aquatics_initialOffer", background:"aquatics_logo.png", choicesKey:"aquatics_firstChoice"}, this.missionChoice);
				break;
				}

			case "FAILED": // Kraken jumped out of system (failed)
				{
				mission.setInstructionsKey(null);
				missionVariables.aquatics_krakenMission = "CASE_CLOSED";
				mission.runScreen({title: "Mission Failed", messageKey:"aquatics_krakenFailure", background:"aquatics_logo.png"});
				break;
				}

			case "SUCCEEDED": // Kraken destroyed during mission (success)
				{
				mission.setInstructionsKey(null);
				missionVariables.aquatics_krakenMission = "CASE_CLOSED";
				missionVariables.aquatics_reputation = 1;
				mission.runScreen({title: "Mission Accomplished", messageKey:"aquatics_krakenSuccess", background:"aquatics_logo.png"});
				break;
				}
				
			case "BRIEFING_2":
				{
				missionVariables.aquatics_krakenMission = "BEGUN";
				mission.runScreen({title: "Mission Briefing", messageKey:"aquatics_krakenBriefing3", background:"aquatics_logo.png"});
				return;
				break;
				}

			case "BRIEFING_1":
				{
				missionVariables.aquatics_krakenMission = "BRIEFING_2";
				mission.runScreen({title: "Mission Briefing", messageKey:"aquatics_krakenBriefing2", model:"aquatics_kraken"});
				return;
				break;
				}

			case "IMMEDIATE_OFFER":
				{
				missionVariables.aquatics_krakenMission = "MAKE_OFFER";
				this.missionScreenOpportunity();
				return;
				break;
				}	

			default: // anything else, including first visit to HQ
				{
				if(!missionVariables.aquatics_krakenMission)
					{
					if(player.score > 511)
						{
						missionVariables.aquatics_krakenMission = "IMMEDIATE_OFFER";
						}
					else
						{ 
						missionVariables.aquatics_krakenMission = "UNAVAILABLE";
						}

					missionVariables.aquatics_timer = clock.days;  // start the equipment appearance clock
					mission.runScreen({title: "Welcome to Aqualina!", messageKey:"aquatics_firstVisit", background:"aquatics_logo.png"});
					}
				break;
				}
			}
		}
	}
