this.name					= "aquatics_ringScript.js";
this.author					= "Thargoid";
this.copyright				= "Creative Commons: attribution, non-commercial, sharealike with clauses - see readme.txt";
this.description			= "Script to add ring of blocks around system main planet in Aqualina system";
this.version				= "2.31";

this.systemWillPopulate = function()
	{
	if(galaxyNumber !== 2 || system.ID !== 99 || !system.mainPlanet || !system.mainStation) 
		{ return; }
	
	var spawnPosition = system.mainPlanet.position;

	this.ringGroup = new ShipGroup("ringGroup");
	
	system.setPopulator("aquatics_Ring", {
		callback: function(pos) {			
			this.$sectionLength = 6000; // orbit circumference divided by segment width (5000m) plus a 1000m gap on each side to prevent collisions (2000m total gap between segments)
			this.$gateCount = 4;
			this.$ringHeight = ((system.mainPlanet.position.distanceTo(system.mainStation.position) - system.mainPlanet.radius) / 2) + system.mainPlanet.radius; // ring orbits half-way between planet surface and main station
			this.$segmentNumber = (2 * Math.PI * this.$ringHeight) / this.$sectionLength; 
			this.$gateFrequency = Math.floor(this.$segmentNumber / this.$gateCount);
			this.$basePosition =  pos;

			this.$segmentNumber = Math.floor(this.$segmentNumber); // ensure we're not trying to spawn a fraction of a segment
			this.$ringHeight = (this.$sectionLength * this.$segmentNumber) /  (2 * Math.PI);
		
			let $vecForward = system.mainPlanet.orientation.vectorForward();
			let $vecUp = system.mainPlanet.orientation.vectorUp();
			let $vecRight = system.mainPlanet.orientation.vectorRight();
	
			let $segmentCounter = 0;
			for($segmentCounter = 0; $segmentCounter < this.$segmentNumber; $segmentCounter++)
				{
				this.$segmentAngle = 2 * Math.PI * ($segmentCounter / this.$segmentNumber);
				this.$jointAngle = 2 * Math.PI * (($segmentCounter + 0.5) / this.$segmentNumber);

				this.$segmentPosition = this.$basePosition.add($vecRight.multiply(this.$ringHeight * Math.sin(this.$segmentAngle))).add($vecForward.multiply(this.$ringHeight * Math.cos(this.$segmentAngle)));

				this.$jointPosition = this.$basePosition.add($vecRight.multiply(this.$ringHeight * Math.sin(this.$jointAngle))).add($vecForward.multiply(this.$ringHeight * Math.cos(this.$jointAngle)));
		
				this.$gateFlag = $segmentCounter / this.$gateFrequency;
				if($segmentCounter > 0 && (this.$gateFlag == Math.floor(this.$gateFlag)))
					{ 
					this.$nextSegment = system.addShips("aquatics_ringGateway", 1, this.$segmentPosition, 0); 
					this.$nextSegment[0].displayName = ("Ring Gateway " + (Math.floor(this.$gateFlag)) + "");	
					this.$nextSegment[0].group = this.ringGroup;
					}
				else
					{ 
					this.$nextSegment = system.addShips("aquatics_ringSegment", 1, this.$segmentPosition, 0); 
					this.$nextSegment[0].group = this.ringGroup;}

				this.$nextSegment[0].orientation = system.mainPlanet.orientation.rotate($vecUp, (this.$segmentAngle * -1));
				this.$nextSegment[0].script.$spawnOrientation = this.$nextSegment[0].orientation;
				this.$nextSegment[0].script.$spawnPosition = this.$nextSegment[0].position;

				// add the joints in between segments
				this.$nextJoint = system.addVisualEffect("aquatics_ringJoint", this.$jointPosition);
				this.$nextJoint.orientation = system.mainPlanet.orientation.rotate($vecUp, (this.$jointAngle * -1));
				this.$nextJoint.group = this.ringGroup;
				}
			}.bind(this),
		location: "COORDINATES",
		coordinates: spawnPosition,
		deterministic: true
		}
	)	
}
